==> enterprisemodules-ora_config-3.2.4.tar.gz: enterprisemodules-ora_config-3.2.4/lib/puppet/type/ora_function.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_function) do
  include EasyType
  extend Puppet_X::EnterpriseModules::Oracle::TitleParser
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::DefaultSid

  desc <<-EOD
  This resource allows you to manage PL/SQL functions in the Oracle database.

      ora_function { 'testuser.return_some_value':
        ensure  => 'present',
        source => '/vagrant/tests/function.sql',
      }

  This puppet definition ensures that the function `testuser.return_some_value` is available
  in the database and that its content matches the content defined in the specified source.

  To decide if the function needs an update, the puppet type compares the content in the database, with
  the content in the source file. This comparison is done insenitive to case, white spacing and used quote's
  (the " or the ` ).

  When you have specified `report_errors => true` (which is the default), the type will fail on PL/SQL
  compilation errors. functions with compilation errors do however end up in the database. On a second Puppet
  run the won't be updated. Puppet reports a warning these resources though?

  ```
  Warning: function TESTUSER.RETURN_SOME_VALUE@test up-to-date, but contains 4 error(s).
  ```

  EOD

  to_get_raw_resources do
    sql_on_all_primary_database_sids "select owner, name  from dba_source where type = 'FUNCTION'"
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  on_destroy do
    [:sql, "drop function #{owner}.#{function_name}", {:sid => sid}]
  end

  def apply
    options = { :sid => sid, :parse => false, :catch_extra_errors => /compilation errors/ }
    options[:failonsqlfail] = report_errors
    statement = "@#{source}\n/\n"

    if cwd
      fail "Working directory '#{cwd}' does not exist" unless File.directory?(cwd)
      FileUtils.cd(cwd)
    end
    output = sql statement, options
    Puppet.debug(output) if logoutput == :true
    nil
  end

  map_title_to_sid(:owner, :function_name) { /(.+)\.(.+)/ }

  ensurable

  parameter :name
  parameter :owner
  parameter :function_name
  parameter :sid
  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :editionable
  parameter :report_errors

  property  :source

  ora_autorequire(:ora_user, :owner)

end

==> enterprisemodules-ora_config-3.9.9.tar.gz: enterprisemodules-ora_config-3.9.9/lib/puppet/type/ora_function.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent.parent.parent + 'easy_type' + 'lib')
require 'easy_type'
require 'puppet_x/enterprisemodules/oracle/access'
require 'puppet_x/enterprisemodules/oracle/title_parser'
require 'puppet_x/enterprisemodules/oracle/default_sid'

Puppet::Type.newtype(:ora_function) do
  include EasyType
  extend Puppet_X::EnterpriseModules::Oracle::TitleParser
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::DefaultSid

  desc <<-EOD
  This resource allows you to manage PL/SQL functions in the Oracle database.

      ora_function { 'testuser.return_some_value':
        ensure  => 'present',
        source => '/vagrant/tests/function.sql',
      }

  This puppet definition ensures that the function `testuser.return_some_value` is available
  in the database and that its content matches the content defined in the specified source.

  To decide if the function needs an update, the puppet type compares the content in the database, with
  the content in the source file. This comparison is done insenitive to case, white spacing and used quote's
  (the " or the ` ).

  When you have specified `report_errors => true` (which is the default), the type will fail on PL/SQL
  compilation errors. functions with compilation errors do however end up in the database. On a second Puppet
  run the won't be updated. Puppet reports a warning these resources though?

  ```
  Warning: function TESTUSER.RETURN_SOME_VALUE@test up-to-date, but contains 4 error(s).
  ```

  EOD

  to_get_raw_resources do
    sql_on_all_primary_database_sids "select owner, name  from dba_source where type = 'FUNCTION'"
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  on_destroy do
    [:sql, "drop function #{owner}.#{function_name}", {:sid => sid}]
  end

  def apply
    options = { :sid => sid, :parse => false, :catch_extra_errors => /compilation errors/ }
    options[:failonsqlfail] = report_errors
    statement = "@#{source}\n/\n"

    if cwd
      fail "Working directory '#{cwd}' does not exist" unless File.directory?(cwd)
      FileUtils.cd(cwd)
    end
    output = sql statement, options
    Puppet.debug(output) if logoutput.to_s == 'true'
    nil
  end

  map_title_to_sid(:owner, :function_name) { /(.+)\.(.+)/ }

  ensurable

  parameter :name
  parameter :owner
  parameter :function_name
  parameter :sid
  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :editionable
  parameter :report_errors

  property  :source

  ora_autorequire(:ora_user, :owner)

end
